# sort

sort the lines of unsorted.txt

    sort unsorted.txt


sort the lines ignoring leading whitespace

    sort -b ignore_whitespace.txt


reverse the sort order

    sort -r reverse.txt


check if file is sorted

    sort -c check_me.txt



# Basic Usage

Sort the lines of a file:

    sort <file>


